@@ -1,10 +1,9 @@
 from .fields import MongoengineConnectionField
 from .fields_async import AsyncMongoengineConnectionField
-
-from .types import MongoengineObjectType, MongoengineInputType, MongoengineInterfaceType
+from .types import MongoengineInputType, MongoengineInterfaceType, MongoengineObjectType
 from .types_async import AsyncMongoengineObjectType
 
-__version__ = "0.1.1"
+__version__ = "0.4.2"
 
 __all__ = [
     "__version__",
